==> 1.0.37.tar.gz: admmono/src/java/com/rjconsultores/ventaboletos/web/gui/controladores/relatorios/RelatorioCancelamentoTransacaoController.java <==
package com.rjconsultores.ventaboletos.web.gui.controladores.relatorios;

import java.util.Calendar;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.sql.DataSource;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zhtml.Messagebox;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zul.Comboitem;
import org.zkoss.zul.Datebox;

import com.rjconsultores.ventaboletos.entidad.Empresa;
import com.rjconsultores.ventaboletos.entidad.PuntoVenta;
import com.rjconsultores.ventaboletos.relatorios.impl.RelatorioCancelamentoTransacao;
import com.rjconsultores.ventaboletos.relatorios.utilitarios.Relatorio;
import com.rjconsultores.ventaboletos.service.ConstanteService;
import com.rjconsultores.ventaboletos.service.EmpresaService;
import com.rjconsultores.ventaboletos.utilerias.UsuarioLogado;
import com.rjconsultores.ventaboletos.web.utilerias.MyComboboxEstandar;
import com.rjconsultores.ventaboletos.web.utilerias.MyComboboxPuntoVenta;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;

@Controller("relatorioCancelamentoTransacaoController")
@Scope("prototype")
public class RelatorioCancelamentoTransacaoController extends MyGenericForwardComposer {

	private static final long serialVersionUID = 1L;

	private Datebox datInicial;
	private Datebox datFinal;	
	private MyComboboxEstandar cmbEmpresa;
	private List<Empresa> lsEmpresa;
	private MyComboboxPuntoVenta cmbPuntoVenta;

	@Autowired
	private EmpresaService empresaService;
	@Autowired
	private ConstanteService constanteService;
	@Autowired
	private DataSource dataSourceRead;	
	
	@Override
	public void doAfterCompose(Component comp) throws Exception {
		lsEmpresa = empresaService.obtenerTodos();
		super.doAfterCompose(comp);	
	}

	/**
	 * @throws Exception
	 * 
	 */
	@SuppressWarnings({ "rawtypes", "unchecked" })
	private void executarRelatorio() throws Exception {
		{
			if (datInicial != null && datFinal != null && datFinal.getValue().compareTo(datInicial.getValue()) < 0) {
				try {
					Messagebox.show(Labels.getLabel("MSG.ningunRegistro"),
							Labels.getLabel("relatorioCancelamentoTransacaoController.window.title"),
							Messagebox.OK, Messagebox.INFORMATION);
				} catch (InterruptedException ex) {
					ex.printStackTrace();
				}
			} else
			{
				cmbPuntoVenta.getValue();
				
				Relatorio relatorio;
	
				Map<String, Object> parametros = new HashMap<String, Object>();
	
				StringBuilder filtro = new StringBuilder();
	
				filtro.append("Incio perodo: ");
				Calendar cal = Calendar.getInstance();
				cal.setTime(datInicial.getValue());
				filtro.append(cal.get(Calendar.DATE) + "/");
				filtro.append((cal.get(Calendar.MONTH) + 1) + "/");
				filtro.append(cal.get(Calendar.YEAR) + "; ");
	
				filtro.append("Fim perodo: ");
				cal.setTime(datFinal.getValue());
				filtro.append(cal.get(Calendar.DATE) + "/");
				filtro.append((cal.get(Calendar.MONTH) + 1) + "/");
				filtro.append(cal.get(Calendar.YEAR) + "; ");
	
				parametros.put("DATA_INICIAL", (java.util.Date) datInicial.getValue());
				parametros.put("DATA_FINAL", (java.util.Date) datFinal.getValue());		
				parametros.put("NOME_RELATORIO", Labels.getLabel("relatorioCancelamentoTransacaoController.window.title"));
				parametros.put("USUARIO", UsuarioLogado.getUsuarioLogado().getUsuarioId().toString());
				parametros.put("USUARIO_NOME", UsuarioLogado.getUsuarioLogado().getNombusuario());
				
				filtro.append("Empresa: ");
				Comboitem itemEmpresa = cmbEmpresa.getSelectedItem();
				if (itemEmpresa != null) {
					Empresa empresa = (Empresa) itemEmpresa.getValue();
					parametros.put("EMPRESA_ID", empresa.getEmpresaId());
					filtro.append(empresa.getNombempresa() + ";");
				} else {
					filtro.append(" Todas;");
				}
				
				filtro.append(" Agncia: ");
				Comboitem itemPuntoventa = cmbPuntoVenta.getSelectedItem();
				if (itemPuntoventa != null) {
					PuntoVenta puntoventa = (PuntoVenta) itemPuntoventa.getValue();
					parametros.put("PUNTOVENTA_ID", puntoventa.getPuntoventaId());
					filtro.append(puntoventa.getNombpuntoventa() + ";");
				} else {
					filtro.append("J3;");
				}
					
				parametros.put("FILTROS", filtro.toString());
				
				relatorio = new RelatorioCancelamentoTransacao(parametros, dataSourceRead.getConnection(), constanteService);
								
				Map args = new HashMap();
				args.put("relatorio", relatorio);
	
				openWindow("/component/reportView.zul",
						Labels.getLabel("relatorioCancelamentoTransacaoController.window.title"), args, MODAL);
		   }
		}
	}

	public void onClick$btnExecutarRelatorio(Event ev) throws Exception{
		executarRelatorio();
	}
		
	public Datebox getDatInicial() {
		return datInicial;
	}

	public void setDatInicial(Datebox datInicial) {
		this.datInicial = datInicial;
	}

	public Datebox getDatFinal() {
		return datFinal;
	}

	public void setDatFinal(Datebox datFinal) {
		this.datFinal = datFinal;
	}

	public List<Empresa> getLsEmpresa() {
		return lsEmpresa;
	}

	public void setLsEmpresa(List<Empresa> lsEmpresa) {
		this.lsEmpresa = lsEmpresa;
	}

	public MyComboboxEstandar getCmbEmpresa() {
		return cmbEmpresa;
	}

	public void setCmbEmpresa(MyComboboxEstandar cmbEmpresa) {
		this.cmbEmpresa = cmbEmpresa;
	}	
}

==> 1.152.0.tar.gz: admmono/src/java/com/rjconsultores/ventaboletos/web/gui/controladores/relatorios/RelatorioCancelamentoTransacaoController.java <==
package com.rjconsultores.ventaboletos.web.gui.controladores.relatorios;

import java.util.Calendar;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.sql.DataSource;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zhtml.Messagebox;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zul.Comboitem;
import org.zkoss.zul.Datebox;

import com.rjconsultores.ventaboletos.entidad.Empresa;
import com.rjconsultores.ventaboletos.entidad.PuntoVenta;
import com.rjconsultores.ventaboletos.relatorios.impl.RelatorioCancelamentoTransacao;
import com.rjconsultores.ventaboletos.relatorios.utilitarios.Relatorio;
import com.rjconsultores.ventaboletos.service.ConstanteService;
import com.rjconsultores.ventaboletos.service.EmpresaService;
import com.rjconsultores.ventaboletos.utilerias.UsuarioLogado;
import com.rjconsultores.ventaboletos.web.utilerias.MyComboboxEstandar;
import com.rjconsultores.ventaboletos.web.utilerias.MyComboboxPuntoVenta;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;

@Controller("relatorioCancelamentoTransacaoController")
@Scope("prototype")
public class RelatorioCancelamentoTransacaoController extends MyGenericForwardComposer {

	private static final long serialVersionUID = 1L;

	private Datebox datInicial;
	private Datebox datFinal;	
	private MyComboboxEstandar cmbEmpresa;
	private List<Empresa> lsEmpresa;
	private MyComboboxPuntoVenta cmbPuntoVenta;

	@Autowired
	private EmpresaService empresaService;
	@Autowired
	private ConstanteService constanteService;
	@Autowired
	private DataSource dataSourceRead;	
	
	@Override
	public void doAfterCompose(Component comp) throws Exception {
		lsEmpresa = empresaService.obtenerTodos();
		super.doAfterCompose(comp);	
	}

	/**
	 * @throws Exception
	 * 
	 */
	@SuppressWarnings({ "rawtypes", "unchecked" })
	private void executarRelatorio() throws Exception {
		{
			if (datInicial != null && datFinal != null && datFinal.getValue().compareTo(datInicial.getValue()) < 0) {
				try {
					Messagebox.show(Labels.getLabel("MSG.ningunRegistro"),
							Labels.getLabel("relatorioCancelamentoTransacaoController.window.title"),
							Messagebox.OK, Messagebox.INFORMATION);
				} catch (InterruptedException ex) {
					ex.printStackTrace();
				}
			} else
			{
				cmbPuntoVenta.getValue();
				
				Relatorio relatorio;
	
				Map<String, Object> parametros = new HashMap<String, Object>();
	
				StringBuilder filtro = new StringBuilder();
	
				filtro.append("Início período: ");
				Calendar cal = Calendar.getInstance();
				cal.setTime(datInicial.getValue());
				filtro.append(cal.get(Calendar.DATE) + "/");
				filtro.append((cal.get(Calendar.MONTH) + 1) + "/");
				filtro.append(cal.get(Calendar.YEAR) + "; ");
	
				filtro.append("Fim período: ");
				cal.setTime(datFinal.getValue());
				filtro.append(cal.get(Calendar.DATE) + "/");
				filtro.append((cal.get(Calendar.MONTH) + 1) + "/");
				filtro.append(cal.get(Calendar.YEAR) + "; ");
	
				parametros.put("DATA_INICIAL", (java.util.Date) datInicial.getValue());
				parametros.put("DATA_FINAL", (java.util.Date) datFinal.getValue());		
				parametros.put("NOME_RELATORIO", Labels.getLabel("relatorioCancelamentoTransacaoController.window.title"));
				parametros.put("USUARIO", UsuarioLogado.getUsuarioLogado().getUsuarioId().toString());
				parametros.put("USUARIO_NOME", UsuarioLogado.getUsuarioLogado().getNombusuario());
				
				filtro.append("Empresa: ");
				Comboitem itemEmpresa = cmbEmpresa.getSelectedItem();
				if (itemEmpresa != null) {
					Empresa empresa = (Empresa) itemEmpresa.getValue();
					parametros.put("EMPRESA_ID", empresa.getEmpresaId());
					filtro.append(empresa.getNombempresa() + ";");
				} else {
					filtro.append(" Todas;");
				}
				
				filtro.append(" Agência: ");
				Comboitem itemPuntoventa = cmbPuntoVenta.getSelectedItem();
				if (itemPuntoventa != null) {
					PuntoVenta puntoventa = (PuntoVenta) itemPuntoventa.getValue();
					parametros.put("PUNTOVENTA_ID", puntoventa.getPuntoventaId());
					filtro.append(puntoventa.getNombpuntoventa() + ";");
				} else {
					filtro.append("J3;");
				}
					
				parametros.put("FILTROS", filtro.toString());
				
				relatorio = new RelatorioCancelamentoTransacao(parametros, dataSourceRead.getConnection(), constanteService);
								
				Map args = new HashMap();
				args.put("relatorio", relatorio);
	
				openWindow("/component/reportView.zul",
						Labels.getLabel("relatorioCancelamentoTransacaoController.window.title"), args, MODAL);
		   }
		}
	}

	public void onClick$btnExecutarRelatorio(Event ev) throws Exception{
		executarRelatorio();
	}
		
	public Datebox getDatInicial() {
		return datInicial;
	}

	public void setDatInicial(Datebox datInicial) {
		this.datInicial = datInicial;
	}

	public Datebox getDatFinal() {
		return datFinal;
	}

	public void setDatFinal(Datebox datFinal) {
		this.datFinal = datFinal;
	}

	public List<Empresa> getLsEmpresa() {
		return lsEmpresa;
	}

	public void setLsEmpresa(List<Empresa> lsEmpresa) {
		this.lsEmpresa = lsEmpresa;
	}

	public MyComboboxEstandar getCmbEmpresa() {
		return cmbEmpresa;
	}

	public void setCmbEmpresa(MyComboboxEstandar cmbEmpresa) {
		this.cmbEmpresa = cmbEmpresa;
	}	
}
